pub enum InstanceAllocationStrategy {
OnDemand,
}Expand description
Represents the module instance allocation strategy to use.
Variants
OnDemand
The on-demand instance allocation strategy.
Resources related to a module instance are allocated at instantiation time and
immediately deallocated when the Store referencing the instance is dropped.
This is the default allocation strategy for Wasmtime.