NoFunc

Struct NoFunc 

pub struct NoFunc { /* private fields */ }
A reference to the abstract nofunc heap value.

The are no instances of (ref nofunc): it is an uninhabited type.

There is precisely one instance of (ref null nofunc), aka nullfuncref: the null reference.

This NoFunc Rust type’s sole purpose is for use with Func::wrap- and Func::typed-style APIs for statically typing a function as taking or returning a (ref null nofunc) (aka Option<NoFunc>) which is always None.

Example

let mut config = Config::new();
config.wasm_function_references(true);
let engine = Engine::new(&config)?;

let module = Module::new(
    &engine,
    r#"
        (module
            (func (export "f") (param (ref null nofunc))
                ;; If the reference is null, return.
                local.get 0
                ref.is_null nofunc
                br_if 0

                ;; If the reference was not null (which is impossible)
                ;; then raise a trap.
                unreachable
            )
        )
    "#,
)?;

let mut store = Store::new(&engine, ());
let instance = Instance::new(&mut store, &module, &[])?;
let f = instance.get_func(&mut store, "f").unwrap();

// We can cast a `(ref null nofunc)`-taking function into a typed function that
// takes an `Option<NoFunc>` via the `Func::typed` method.
let f = f.typed::<Option<NoFunc>, ()>(&store)?;

// We can call the typed function, passing the null `nofunc` reference.
let result = f.call(&mut store, NoFunc::null());

// The function should not have trapped, because the reference we gave it was
// null (as it had to be, since `NoFunc` is uninhabited).
assert!(result.is_ok());

Implementations

Source

impl NoFunc

pub fn null() -> Option<NoFunc>

Get the null (ref null nofunc) (aka nullfuncref) reference.

pub fn null_ref() -> Ref

Get the null (ref null nofunc) (aka nullfuncref) reference as a Ref.

pub fn null_val() -> Val

Get the null (ref null nofunc) (aka nullfuncref) reference as a Val.